import fedmsg
import fedmsg.encoding
import fedmsg.consumers

from . import config
from .jobtrigger import JobTrigger
from . import exceptions as exc


def _pull_version_release(compose_id):
    """Splits out the relevant bits of the compose ID. Input requires the form
    "Fedora-TYPE-VERSION-Date.Serial" (ie, Fedora-Cloud-24-20170224.0) that fedmsg
    spits out in compose_id."""

    parts = compose_id.split('-')
    if len(parts) < 4:
        raise exc.TriggerMsgError("Provided compose_id did not contain"
                                  "all parts.")
    else:
        name = '-'.join(parts[:2])
        version = parts[1]
        release = parts[2]

        return name, version, release


def _process(msg):
    """This method preps the incoming fedmsg data so the trigger can set
    off the task. Expects fedmsg.body data as input and returns a dict
    for JobTrigger.do_trigger."""

    MESSAGE_TYPE = "CloudCompose"

    if msg['msg']['status'] != "FINISHED":
        raise exc.TriggerMsgError("Rejecting message because status not "
                                  "'FINISHED'.")

    # Split this up to make the lines shorter
    # FIXME: We shouldn't hard code these paths here
    item = ("{0}/CloudImages/x86_64/"
            "images/{1}.x86_64.qcow2").format(msg['msg']['location'],
                                              msg['msg']['compose_id'])

    name, version, release = _pull_version_release(msg['msg']['compose_id'])

    if version == "Atomic":
        MESSAGE_TYPE = "AtomicCompose"

    data = {
        "_msg": msg,
        "message_type": MESSAGE_TYPE,
        "item": item,
        "item_type": 'compose',
        "name": name,
        "version": version,
        "release": release,
    }

    return data


class CloudComposeJobTrigger(JobTrigger):

    def process(self, msg):
        return _process(msg)


class CloudComposeCompletedConsumer(fedmsg.consumers.FedmsgConsumer):
    jsonify = False
    topic = "org.fedoraproject.{}.pungi.compose.status.change".format(config.deployment_type)
    config_key = "taskotron.cloudcomposecompletedconsumer.enabled"

    def __init__(self, *args, **kw):
        super(CloudComposeCompletedConsumer, self).__init__(*args, **kw)
        self.trigger = CloudComposeJobTrigger(self.log)

    def consume(self, message):
        msg = fedmsg.encoding.loads(message.body)
        try:
            data = self.trigger.process(msg)
            self.trigger.do_trigger(data)
        except exc.TriggerMsgError, e:
            self.log.debug(e)
            return
