import pytest
import json

# Only going to import the interesting bits
from jobtriggers import cloud_compose_complete_msg
from jobtriggers import exceptions as exc

# Set up some dummy data to work with that's in various states of correct
# These comprise just the interesting bits from the fedmsg that we want to
# consume with our trigger.

location = "http://kojipkgs.fedoraproject.org/compose/Fedora-Cloud-24-20170224.0/compose"

template_msg = ('{"msg": { "status": "FINISHED",'
                '"location":'
                '"http://kojipkgs.fedoraproject.org/compose/Fedora-Cloud-24-20170224.0/compose",'
                '"compose_id": ""}}')

msg_good = json.loads(template_msg)
msg_good['msg']['compose_id'] = "Fedora-Cloud-24-20170302.0"

msg_bad_compose_id = json.loads(template_msg)
msg_bad_compose_id['msg']['compose_id'] = "Fedora-Cloud-23"

msg_atomic = json.loads(template_msg)
msg_atomic['msg']['compose_id'] = "Fedora-Atomic-25-20170302.0"


def test_process():
    """Test that nothing fails with known good data."""
    data = cloud_compose_complete_msg._process(msg_good)
    assert data['message_type'] == 'CloudCompose'
    assert data['name'] == 'Fedora-Cloud'
    assert data['version'] == 'Cloud'
    assert data['release'] == '24'


def test_process_atomic():
    """Test that the detection of Atomic composes sets the correct
    message_type, which would be "AtomicCompose"."""
    data = cloud_compose_complete_msg._process(msg_atomic)

    print data

    assert data['name'] == "Fedora-Atomic"
    assert data['version'] == "Atomic"
    assert data['message_type'] == "AtomicCompose"


def test_pull_version_release():
    """Ensure that execution failes if the 'compose_id' is malformed."""
    with pytest.raises(exc.TriggerMsgError):
        cloud_compose_complete_msg._process(msg_bad_compose_id)
